==> mediawiki-1.12.4.tbz: www/mediawiki/languages/messages/MessagesUg.php <==
<?php
/** Uighur (Uyghurche‎ / ئۇيغۇرچە)
 *
 * @ingroup Language
 * @file
 *
 * @author לערי ריינהארט
 */

$rtl = true;

$messages = array(
# Dates
'sunday'    => 'Yakshanbe',
'tuesday'   => 'Seyshanbe',
'wednesday' => 'Qarshenbe',
'thursday'  => 'Payshanbe',
'saturday'  => 'Shanba',

'qbedit'     => 'Uzgartish',
'navigation' => 'كۆرۈش',

'search'           => 'Izdash',
'searchbutton'     => 'Izdash',
'go'               => 'Kuchush',
'searcharticle'    => 'Kuchush',
'history_short'    => 'Tarih',
'printableversion' => 'Basma Nushisi',
'permalink'        => 'Manguluk Bet',
'edit'             => 'Uzgartish',
'delete'           => 'Yukhutush',
'protect'          => 'Koghdash',
'talkpagelinktext' => 'Monazire',
'talk'             => 'Monazire',
'toolbox'          => 'Kural Sandukleri',
'otherlanguages'   => 'Bashkha tillarda',
'jumptosearch'     => 'izdash',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents' => 'Hazirkhi Wakhalar',
'edithelp'      => 'Uzgartish yardemi',
'mainpage'      => 'Bash Bet',
'portal'        => 'Tor Jamiyeti',
'sitesupport'   => 'Iana Toplash',

'editsection' => 'uzgartish',
'editold'     => 'uzgartish',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-user' => 'Ishletkuqi tor beti',

# Login and logout pages
'yourname'          => 'Ishletkuqi ismi:',
'yourpassword'      => 'Achkuch:',
'yourpasswordagain' => 'Achkuchni khayta besing:',
'logout'            => 'Chiqish',
'username'          => 'Ishletkuqi ismi:',

# Edit pages
'summary'     => 'Hulasa',
'minoredit'   => 'Bu Kichik Uzgartish',
'watchthis'   => 'Bu Batka Kharang',
'showpreview' => 'Aldinala kurux',
'showdiff'    => 'Uzgurushlerni kursutung',

# Search results
'powersearch' => 'Izdash',

# Preferences page
'searchresultshead' => 'Izdash',

# Recent changes
'recentchanges' => 'Yengi Uzgurush',

# Recent changes linked
'recentchangeslinked' => 'Yekhinkhi Uzgurushler',

# Upload
'upload'          => 'Yengi Hujjat Kirguzush',
'uploadbtn'       => 'Yengi Hujjat Kirguzush',
'filedesc'        => 'Hulasa',
'watchthisupload' => 'Bu Batka Kharang',

# Image list
'ilsubmit' => 'Izdash',

# File deletion
'filedelete-submit' => 'Yukhutush',

# Random page
'randompage' => 'Halighan Tor Beti',

'brokenredirects-edit'   => '(uzgartish)',
'brokenredirects-delete' => '(yukhutush)',

# Miscellaneous special pages
'specialpages'      => 'Alahida Tor Batleri',
'newpages-username' => 'Ishletkuqi ismi:',
'move'              => 'Yotkash',

# Book sources
'booksources-go' => 'Kuchush',

# Special:Log
'log-search-submit' => 'Kuchush',

# Special:Allpages
'allpagessubmit' => 'Kuchush',

# Watchlist
'watchlist'     => 'Men kharawatkhan tor betleri',
'watch'         => 'Karang',
'watchthispage' => 'Bu Batka Kharang',

# Restrictions (nouns)
'restriction-edit' => 'Uzgartish',
'restriction-move' => 'Yotkash',

# Undelete
'undelete-search-submit' => 'Izdash',

'sp-contributions-submit' => 'Izdash',

# What links here
'whatlinkshere' => 'Bashkha Tor Batleri',

# Block/unblock
'ipblocklist-submit' => 'Izdash',

# Move page
'move-watch' => 'Bu Batka Kharang',

# Namespace 8 related
'allmessages' => 'System havarleri',

# Tooltip help for the actions
'tooltip-ca-move' => 'Bu batni yotkang',
'tooltip-search'  => 'Izdash {{SITENAME}}',
'tooltip-p-logo'  => 'Bash Bet',

# Trackbacks
'trackbackremove' => ' ([$1 Yukhutush])',

# Multipage image navigation
'imgmultigo' => 'Kuchush!',

# Table pager
'table_pager_limit_submit' => 'Kuchush',

);

==> mediawiki-1.14.1.tbz: www/mediawiki/languages/messages/MessagesUg.php <==
<?php
/** Uighur (Uyghurche‎ / ئۇيغۇرچە)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Jose77
 * @author לערי ריינהארט
 */

$rtl = true;

$messages = array(
# Dates
'sunday'    => 'Yakshanbe',
'tuesday'   => 'Seyshanbe',
'wednesday' => 'Qarshenbe',
'thursday'  => 'Payshanbe',
'saturday'  => 'Shanba',
'january'   => 'Yanwar',
'february'  => 'Féwral',
'march'     => 'Mart',
'april'     => 'Aprél',
'june'      => 'Iyun',
'july'      => 'Iyul',
'august'    => 'Awghust',
'september' => 'Séntebr',
'october'   => 'Öktebir',
'november'  => 'Noyabr',
'december'  => 'Dékabr',
'may'       => 'May',

'qbedit'     => 'Uzgartish',
'navigation' => 'كۆرۈش',

'search'           => 'Izdash',
'searchbutton'     => 'Izdash',
'go'               => 'Kuchush',
'searcharticle'    => 'Kuchush',
'history_short'    => 'Tarih',
'printableversion' => 'Basma Nushisi',
'permalink'        => 'Manguluk Bet',
'edit'             => 'Uzgartish',
'delete'           => 'Yukhutush',
'protect'          => 'Koghdash',
'talkpagelinktext' => 'Monazire',
'talk'             => 'Monazire',
'toolbox'          => 'Kural Sandukleri',
'otherlanguages'   => 'Bashkha tillarda',
'jumptosearch'     => 'izdash',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Hazirkhi Wakhalar',
'edithelp'             => 'Uzgartish yardemi',
'mainpage'             => 'Bash Bet',
'mainpage-description' => 'Bash Bet',
'portal'               => 'Tor Jamiyeti',

'editsection' => 'uzgartish',
'editold'     => 'uzgartish',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-user' => 'Ishletkuqi tor beti',

# Login and logout pages
'yourname'          => 'Ishletkuqi ismi:',
'yourpassword'      => 'Achkuch:',
'yourpasswordagain' => 'Achkuchni khayta besing:',
'logout'            => 'Chiqish',
'username'          => 'Ishletkuqi ismi:',

# Edit pages
'summary'     => 'Hulasa:',
'minoredit'   => 'Bu Kichik Uzgartish',
'watchthis'   => 'Bu Batka Kharang',
'showpreview' => 'Aldinala kurux',
'showdiff'    => 'Uzgurushlerni kursutung',

# Search results
'powersearch' => 'Izdash',

# Preferences page
'searchresultshead' => 'Izdash',

# Recent changes
'recentchanges' => 'Yengi Uzgurush',

# Recent changes linked
'recentchangeslinked' => 'Yekhinkhi Uzgurushler',

# Upload
'upload'          => 'Yengi Hujjat Kirguzush',
'uploadbtn'       => 'Yengi Hujjat Kirguzush',
'filedesc'        => 'Hulasa',
'watchthisupload' => 'Bu Batka Kharang',

# File deletion
'filedelete-submit' => 'Yukhutush',

# Random page
'randompage' => 'Halighan Tor Beti',

'brokenredirects-edit'   => '(uzgartish)',
'brokenredirects-delete' => '(yukhutush)',

# Miscellaneous special pages
'newpages-username' => 'Ishletkuqi ismi:',
'move'              => 'Yotkash',

# Book sources
'booksources-go' => 'Kuchush',

# Special:AllPages
'allpagessubmit' => 'Kuchush',

# Watchlist
'watchlist'     => 'Men kharawatkhan tor betleri',
'watch'         => 'Karang',
'watchthispage' => 'Bu Batka Kharang',

# Restrictions (nouns)
'restriction-edit' => 'Uzgartish',
'restriction-move' => 'Yotkash',

# Undelete
'undelete-search-submit' => 'Izdash',

'sp-contributions-submit' => 'Izdash',

# What links here
'whatlinkshere' => 'Bashkha Tor Batleri',

# Block/unblock
'ipblocklist-submit' => 'Izdash',

# Move page
'move-watch' => 'Bu Batka Kharang',

# Namespace 8 related
'allmessages' => 'System havarleri',

# Tooltip help for the actions
'tooltip-ca-move' => 'Bu batni yotkang',
'tooltip-search'  => 'Izdash {{SITENAME}}',
'tooltip-p-logo'  => 'Bash Bet',

# Special:NewFiles
'ilsubmit' => 'Izdash',

# Trackbacks
'trackbackremove' => ' ([$1 Yukhutush])',

# Multipage image navigation
'imgmultigo' => 'Kuchush!',

# Table pager
'table_pager_limit_submit' => 'Kuchush',

# Special:SpecialPages
'specialpages' => 'Alahida Tor Batleri',

);
